<?php

declare(strict_types=1);

namespace Drupal\navigation_plus;

use Drupal\Core\Entity\EntityInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * @todo Add class description.
 */
final class FlagNewPage {

  /**
   * Constructs a FlagNewPage object.
   */
  public function __construct(
    private readonly NavigationPlusUi $navigationPlusUi,
    private readonly RequestStack $requestStack,
  ) {}

  /**
   * Flag new entity.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *  An entity that was just created.
   *
   * @return void
   */
  public function flagNewEntity(EntityInterface $entity): void {
    $session = $this->requestStack->getCurrentRequest()->getSession();
    $just_created = $session->get('just_created', []);
    $just_created[$entity->bundle()][$entity->id()] = $entity->id();
    $session->set('just_created', $just_created);
  }


  /**
   * Inform front end of new entity.
   *
   * @param array $variables
   *   The page render array.
   *
   * @return void
   */
  public function informFrontEndOfNewEntity(array &$variables) {
    $entity = $this->navigationPlusUi->deriveEntityFromRoute();
    if (!empty($entity)) {
      $session = $this->requestStack->getCurrentRequest()->getSession();
      $just_created = $session->get('just_created', []);
      if (!empty($just_created[$entity->bundle()][$entity->id()])) {
        $variables['#attached']['drupalSettings']['navigationPlus']['justCreated'] = 'true';
      }
    }
  }

}
